pub enum DocMutation {
Set {
path: String,
value: Value,
},
Del {
path: String,
},
Incr {
path: String,
delta: f64,
},
Push {
path: String,
value: Value,
},
Pull {
path: String,
value: Value,
},
}Expand description
Mutation operation used by DocEngine::update.
Variants
Set
Set a field path to a JSON value, creating missing intermediate objects.
Fields
Del
Delete one field path when present.
Incr
Increment an existing numeric field by delta.
Push
Append one JSON value to an array field, creating the array when missing.
Pull
Remove all array items that exactly match the supplied value.